@@ -19,4 +19,4 @@ class FilterSettings:
     return self.__filter_rules_map.get(project_id) or []
 
   def to_dict(self):
-    return {k: map(lambda rule: rule.to_dict(), v) for k, v in self.__filter_rules_map.items()}
\ No newline at end of file
+    return {k: list(map(lambda rule: rule.to_dict(), v)) for k, v in self.__filter_rules_map.items()}
\ No newline at end of file
